Learn R Programming

tdata (version 0.3.0)

oil_price: Data for Vignette

Description

This is oil price data from 2010 retrieved by using the following code: oil_price <- Quandl::Quandl("OPEC/ORB", start_date="2010-01-01") It is saved due to the fact that CRAN checks may fail if the vignette relies on an external API call.

Usage

oil_price

Arguments

Format

A data.frame with 2 columns: Date and Value